pypushover-logger
=================

A simple logging handler that will push notification to Pushover.

All credits goes to: https://gist.github.com/snorrelo/28ab89d142ea93d363a34a8ce115b7cf

The code hosted here is simply a packaged and black-ed version of the code above.